@@ -212,8 +212,8 @@ static void apc_cache_wlocked_gc(apc_cache_t* cache)
 				/* good ol' whining */
 				if (dead->ref_count > 0) {
 					apc_debug(
-						"GC cache entry '%s' was on gc-list for %ld seconds",
-						ZSTR_VAL(dead->key), gc_sec
+						"GC cache entry '%s' was on gc-list for %lld seconds",
+						ZSTR_VAL(dead->key), (long long) gc_sec
 					);
 				}
 
@@ -273,9 +273,9 @@ PHP_APCU_API int APC_UNSERIALIZER_NAME(php) (APC_UNSERIALIZER_ARGS)
 	result = php_var_unserialize(value, &tmp, buf + buf_len, &var_hash);
 	PHP_VAR_UNSERIALIZE_DESTROY(var_hash);
 	BG(serialize_lock)--;
-	
+
 	if (!result) {
-		php_error_docref(NULL, E_NOTICE, "Error at offset %ld of %ld bytes", (zend_long)(tmp - buf), (zend_long)buf_len);
+		php_error_docref(NULL, E_NOTICE, "Error at offset %td of %zd bytes", tmp - buf, buf_len);
 		ZVAL_NULL(value);
 		return 0;
 	}
@@ -1100,7 +1100,7 @@ PHP_APCU_API zend_bool apc_cache_info(zval *info, apc_cache_t *cache, zend_bool
 		add_assoc_long(info, "start_time", cache->header->stime);
 		array_add_double(info, apc_str_mem_size, (double) cache->header->mem_size);
 
-#if APC_MMAP
+#ifdef APC_MMAP
 		add_assoc_stringl(info, "memory_type", "mmap", sizeof("mmap")-1);
 #else
 		add_assoc_stringl(info, "memory_type", "IPC shared", sizeof("IPC shared")-1);
@@ -1210,7 +1210,7 @@ PHP_APCU_API zend_bool apc_cache_defense(apc_cache_t *cache, zend_string *key, t
 			last->len == ZSTR_LEN(key) &&
 			last->mtime == t &&
 			(last->owner_pid != owner_pid
-#if ZTS
+#ifdef ZTS
 			 || last->owner_thread != owner_thread
 #endif
 			)
